@@ -3,9 +3,9 @@ use clap::Parser;
 mod args;
 mod controller;
 mod game;
+mod guess;
 mod keyboard;
 mod letters;
-mod state;
 mod terminal;
 
 use args::{App, GameMode};
@@ -20,6 +20,7 @@ fn main() -> eyre::Result<()> {
         Some(GameMode::Custom(custom)) => Game::custom(custom.word)?,
         Some(GameMode::Day(day)) => Game::from_day(day.day)?,
         Some(GameMode::Random) => Game::from_day(rand::thread_rng().gen())?,
+        Some(GameMode::Date(date)) => Game::from_date(date.date)?,
     };
 
     let controller = GameController::new(game)?;
